aboutsummaryrefslogtreecommitdiff
path: root/gdb/blockframe.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/blockframe.c')
-rw-r--r--gdb/blockframe.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/blockframe.c b/gdb/blockframe.c
index 94ccb29..d35c24a 100644
--- a/gdb/blockframe.c
+++ b/gdb/blockframe.c
@@ -265,8 +265,8 @@ reinit_frame_cache (void)
{
flush_cached_frames ();
- /* FIXME: The inferior_pid test is wrong if there is a corefile. */
- if (inferior_pid != 0)
+ /* FIXME: The inferior_ptid test is wrong if there is a corefile. */
+ if (PIDGET (inferior_ptid) != 0)
{
select_frame (get_current_frame (), 0);
}